Skip to contents

The Stegomyia indices are calculated for each sampling. Once the data have been loaded with function "load_rwa_data" and changed type data of function "clean_raw_data", select study type and date variable using the following formulas: - Container Index(CI): (number of infected containers/total number of containers) * 100. - House Index (HI): (number of infected houses /total number of houses) * 100. - Breteau Index (BI): (number of positive containers/number of houses explored) * 100.

Usage

get_stegomyia_indices_by_type_of_study_and_star_date(
  df,
  st = "Verificacion",
  date = "2021/01/07"
)

Arguments

df

the dataframe with information processed by the function "clean_raw_data".

st

a string of type of study selected, "Encuesta" or "Verificacion". By default, it is set to "Verificacion".

date

a string with the date used to calculate the stegomyia indices. By default, it is set to "2021/01/07".

Value

The dataframe with Stegomyia indices of the selection of type of study and date.

Examples


df_stegomyia_sd <- get_stegomyia_indices_by_type_of_study_and_star_date(df_indx,
                                                     st = "Verificacion",
                                                     date = "2021/01/06")
head(df_stegomyia_sd)
#>   Sector        HI       CI        BI index_status_HI index_status_CI
#> 1    403  7.246377 3.157895  8.695652      Emergencia          Alarma
#> 2    540 12.000000 5.357143 12.000000      Emergencia      Emergencia
#> 3    858 12.000000 5.357143 12.000000      Emergencia      Emergencia
#> 4    869  7.246377 3.157895  8.695652      Emergencia          Alarma
#>   index_status_BI
#> 1      Emergencia
#> 2      Emergencia
#> 3      Emergencia
#> 4      Emergencia